@@ -1,8 +1,9 @@
 #!/usr/bin/env python3
 
-
 from enum import Enum
 
-class OnOffEnum(str, Enum):
+
+class OnOffToggleEnum(str, Enum):
     on = "on"
-    off = "off"
\ No newline at end of file
+    off = "off"
+    toggle = "toggle"
